@@ -5,7 +5,7 @@ use strict;
 use utf8;
 use base 'POD2::Base';
 
-our $VERSION = '5.12.3.01_2';
+our $VERSION = '5.12.3.01_3';
 
 my $pods = {
     perlintro   => '5.12.3',
@@ -67,7 +67,7 @@ consultar la documentacin:
 
   %> perldoc POD2::ES::<nombre_de_pod>
 
-=head1 EXTENSIN DE perldoc
+=head1 ACTUALIZACIN DE perldoc
 
 Por desgracia, los tiles modificadores C<-f> y C<-q> de C<perldoc> no
 funcionan con la documentacin traducida.
@@ -93,8 +93,7 @@ para no tener que escribir el modificador C<-L> cada vez:
  
 Puede aplicar la revisin con la lnea siguiente: 
 
-  %> patch -p0 `/ruta_de_perl -MPod::Perldoc -e 'print
-$INC{"Pod/Perldoc.pm"}'` < /ruta/Perldoc.pm-3.14-patch
+  %> patch -p0 `/ruta_de_perl -MPod::Perldoc -e 'print $INC{"Pod/Perldoc.pm"}'` < /ruta/Perldoc.pm-3.14-patch
 
 La revisin se incluye con esta distribucin y se encuentra en
 F<./patches/Perldoc.pm-3.14-patch>.
@@ -165,8 +164,60 @@ L<http://github.com/zipf/perldoc-es>.
 
 =head1 AUTORES
 
-=item * Joaqun Ferrero  C< explorer at joaquinferrero.com >
-=item * Enrique Nell  C< blas.gordon at gmail.com E<gt >
+=over
+
+=item * Joaqun Ferrero, C< explorer at joaquinferrero.com >
+
+=item * Enrique Nell, C< blas.gordon at gmail.com >
+
+=back
+
+=head1 NOTAS SOBRE LA TRADUCCIN
+
+Para este proyecto hemos tomado las siguientes decisiones:
+
+=over
+
+=item * No utilizar caracteres acentuados en los nombres de variables y
+funciones de los ejemplos de cdigo
+
+Es perfectamente posible utilizarlos, (solo hay que codificar el programa
+como UTF-8 y agregar "use utf8;" al principio), pero teniendo en mente a
+ese programador ms impulsivo, que valora su tiempo y no quiere perderse en
+reflexiones ni verse encorsetado por las normas del lenguaje, creemos que
+as resultar ms fcil probar el cdigo de los ejemplos.
+
+Por otra parte, en aquellos sistemas que cuenten con un sistema antiguo de
+visualizacin de texto, como los terminales de lnea de comandos, es posible
+que se pierdan los acentos. En la mayor parte de los casos ser debido
+a la presencia de una versin de groff (programa utilizado por los comandos
+man y perldoc) que no admite dichos caracteres. En la documentacin
+HTML no debera haber problemas.
+
+
+=item * No traducir los trminos "array" y "hash"
+
+Si tenemos en cuenta que Perl tiene ms de 20 aos y que la inmensa mayora
+de los libros disponibles sobre este lenguaje estn en ingls, a nadie extraar
+que la comunidad de habla hispana se refiera a estos tipos de datos por su
+nombre en ingls. Existen posibles traducciones, como "matriz", "lista" o
+"arreglo" para "array", o "diccionario" para "hash", pero su uso no se ha
+extendido, por lo que hemos preferido utilizar su nombre original.
+Creemos que esto facilitar la lectura de la documentacin.
+
+
+=item * Utilizar "espaol neutro"
+
+El "espaol neutro" es un espaol controlado que pretende evitar el uso de
+trminos ofensivos o de construcciones poco frecuentes en determinados pases
+de habla hispana, con el objetivo de lograr traducciones vlidas para 
+Espaa y Latinoamrica.
+
+=back
+
+=head1 REFERENCIAS
+
+Proyecto OmegaT: L<http://omegat.org/>
 
 
 =head1 VEA TAMBIN
@@ -215,6 +266,8 @@ L<http://search.cpan.org/dist/POD2-ES/>
 
 =head1 AGRADECIMIENTOS
 
+Los autores desean expresar su agradecimiento al equipo de desarrollo
+de OmegaT, la herramienta utilizada para la traduccin.
 
 =head1 LICENCIA Y COPYRIGHT
 
